var path = require("path");
var fs = require("fs");
var process = require("process");
const bundleJson = require('./bundle.json');

function absDir(folder) {
  return path.resolve(path.join(process.cwd(), folder))
}
const runShellCmd = (shelljs, cmd, needHandleResult = true) => {
  const shellResult = cmd(shelljs);
  if (needHandleResult) {
    if (shellResult.code !== 0) {
      process.exitCode = -1;
      throw shellResult.stderr;
    }
  }
  return shellResult;
}

function clean(args, hpmApi) {
  const folder = args[1].length > 0 ? "nouse" : "ohos_bundles"
  if (fs.existsSync(absDir(folder))) {
    runShellCmd(hpmApi.shelljs, shell => shell.rm('-rf', absDir(folder)));
  }
}

module.exports = (hpmApi) => {
  registI18nResource(hpmApi);
  const options = {
    description: hpmApi.i18n.getMessage(`${bundleJson.name}.description`),
    options: {
      "-d,--dir": hpmApi.i18n.getMessage(`${bundleJson.name}.dir`)
    }
  }
  hpmApi.registerCmd('clean', options, (...args) => {
    clean(args, hpmApi);
  })
}

function registI18nResource(hpmApi) {
  const en = {
    "description": "Publish a package to HPM, support type 'gradle','maven','npm'",
    "dir": "arguments error: type is not supported!"
  };
  const zh = {
    "description": "清理ohos_bundles或指定目录",
    "dir": "要清理的目录"
  }

  hpmApi.i18n.addLocalization("en", en, { pluginName: bundleJson.name });
  hpmApi.i18n.addLocalization("zh", zh, { pluginName: bundleJson.name });
}